@@ -32,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.48';
+our $VERSION = '2.49';
 
 =head1 SYNOPSIS
 
@@ -809,7 +809,8 @@ sub process_lines {
 
         if($line =~ m/\\$/){
             $self->add_batch($line);
-            next;
+            #next;
+            return;
         }
         elsif( $self->match_cmd(qr/^wait$/) ){
             #submit this batch and get the job id so the next can depend upon it
